@@ -1,14 +1,20 @@
 """
 Annotation runs framework.
 
-| Copyright 2017-2023, Voxel51, Inc.
+| Copyright 2017-2025, Voxel51, Inc.
 | `voxel51.com <https://voxel51.com/>`_
 |
 """
-from fiftyone.core.runs import Run, RunConfig, RunInfo, RunResults
+from fiftyone.core.runs import (
+    BaseRun,
+    BaseRunConfig,
+    BaseRunInfo,
+    BaseRunResults,
+)
+from fiftyone.core.odm import patch_annotation_runs
 
 
-class AnnotationInfo(RunInfo):
+class AnnotationInfo(BaseRunInfo):
     """Information about an annotation run on a dataset.
 
     Args:
@@ -23,7 +29,7 @@ class AnnotationInfo(RunInfo):
         return AnnotationMethodConfig
 
 
-class AnnotationMethodConfig(RunConfig):
+class AnnotationMethodConfig(BaseRunConfig):
     """Base class for configuring :class:`AnnotationMethod` instances.
 
     Args:
@@ -31,10 +37,16 @@ class AnnotationMethodConfig(RunConfig):
             their parsing
     """
 
-    pass
+    @property
+    def type(self):
+        return "annotation"
+
+    @property
+    def method(self):
+        return None
 
 
-class AnnotationMethod(Run):
+class AnnotationMethod(BaseRun):
     """Base class for annotation methods.
 
     Args:
@@ -57,8 +69,12 @@ class AnnotationMethod(Run):
     def _results_cache_field(cls):
         return "_annotation_cache"
 
+    @classmethod
+    def _patch_function(cls):
+        return patch_annotation_runs
 
-class AnnotationResults(RunResults):
+
+class AnnotationResults(BaseRunResults):
     """Base class for annotation run results."""
 
     pass
