@@ -1,10 +1,11 @@
 """
 Sample media utilities.
 
-| Copyright 2017-2023, Voxel51, Inc.
+| Copyright 2017-2025, Voxel51, Inc.
 | `voxel51.com <https://voxel51.com/>`_
 |
 """
+import eta.core.image as etai
 import eta.core.video as etav
 
 
@@ -12,7 +13,9 @@ import eta.core.video as etav
 VIDEO = "video"
 IMAGE = "image"
 POINT_CLOUD = "point-cloud"
-MEDIA_TYPES = {IMAGE, VIDEO, POINT_CLOUD}
+THREE_D = "3d"
+UNKNOWN = "unknown"
+MEDIA_TYPES = {IMAGE, VIDEO, POINT_CLOUD, THREE_D, UNKNOWN}
 
 # Special media types
 GROUP = "group"
@@ -28,13 +31,19 @@ def get_media_type(filepath):
     Returns:
         the media type
     """
+    if etai.is_image_mime_type(filepath):
+        return IMAGE
+
     if etav.is_video_mime_type(filepath):
         return VIDEO
 
     if filepath.endswith(".pcd"):
         return POINT_CLOUD
 
-    return IMAGE
+    if filepath.endswith(".fo3d"):
+        return THREE_D
+
+    return UNKNOWN
 
 
 class MediaTypeError(TypeError):
@@ -46,16 +55,24 @@ class MediaTypeError(TypeError):
 class SelectGroupSlicesError(ValueError):
     """Exception raised when a grouped collection is passed to a method that
     expects a primitive media type to be selected.
+
+    Args:
+        supported_media_types (None): an optional media type or iterable of
+            media types that are supported
     """
 
-    def __init__(self, supported_media_types):
-        if not isinstance(supported_media_types, str):
-            supported_media_types = "/".join(supported_media_types)
+    def __init__(self, supported_media_types=None):
+        if isinstance(supported_media_types, str):
+            type_str = supported_media_types + " "
+        elif supported_media_types is not None:
+            type_str = "/".join(supported_media_types) + " "
+        else:
+            type_str = ""
 
         message = (
             "This method does not directly support grouped collections. "
-            "You must use `select_group_slices()` to select %s slice(s) to "
+            "You must use `select_group_slices()` to select %sslice(s) to "
             "process"
-        ) % supported_media_types
+        ) % type_str
 
         super().__init__(message)
