@@ -238,16 +238,45 @@ def establish_db_conn(config):
         _update_fc_version(_client)
 
 
+def _is_client_closed(client):
+    # check if the pymongo or motor client is closed or None
+    if client is None:
+        return True
+
+    # check pymongo client
+    if getattr(client, "_closed", False):
+        return True
+
+    # check motor client
+    if isinstance(client, mtr.AsyncIOMotorClient):
+        return getattr(client.delegate, "_closed", False)
+
+    return False
+
+
 def _connect():
     global _client
-    if _client is None:
-        global _connection_kwargs
-
+    if _is_client_closed(_client):
+        _client = None
         establish_db_conn(fo.config)
 
 
 def _disconnect():
     global _client, _async_client
+    # Explicitly call close to ensure that client and
+    # server-side resources are freed
+    # https://jira.mongodb.org/browse/PYTHON-3606
+    if _client:
+        try:
+            _client.close()
+        except Exception:
+            ...
+    if _async_client:
+        try:
+            _async_client.close()
+        except Exception:
+            ...
+
     _client = None
     _async_client = None
     mongoengine.disconnect_all()
@@ -259,7 +288,7 @@ def _async_connect(use_global=False):
     _connect()
 
     global _async_client
-    if not use_global or _async_client is None:
+    if not use_global or _is_client_closed(_async_client):
         global _connection_kwargs
         client = mtr.AsyncIOMotorClient(
             **_connection_kwargs, appname=foc.DATABASE_APPNAME
@@ -472,6 +501,16 @@ def get_db_conn():
     return _apply_options(db)
 
 
+def get_db_version():
+    """Returns the database version.
+
+    Returns:
+        a ``packaging.version.Version``
+    """
+    client = get_db_client()
+    return Version(client.server_info()["version"])
+
+
 def get_async_db_client(use_global=False):
     """Returns an async database client.
 
