@@ -140,6 +140,10 @@ class DelegatedOperationRepo(object):
         """Count all operations."""
         raise NotImplementedError("subclass must implement count()")
 
+    def ping(self, _id: ObjectId) -> DelegatedOperationDocument:
+        """Updates the updated_at field of an operation to keep it alive."""
+        raise NotImplementedError("subclass must implement ping()")
+
 
 class MongoDelegatedOperationRepo(DelegatedOperationRepo):
     COLLECTION_NAME = "delegated_ops"
@@ -189,11 +193,11 @@ class MongoDelegatedOperationRepo(DelegatedOperationRepo):
                 )
             )
 
-        if "group_id_1" not in index_names:
+        if "parent_id_1" not in index_names:
             indices_to_create.append(
                 IndexModel(
-                    [("group_id", pymongo.ASCENDING)],
-                    name="group_id_1",
+                    [("parent_id", pymongo.ASCENDING)],
+                    name="parent_id_1",
                 )
             )
 
@@ -209,7 +213,7 @@ class MongoDelegatedOperationRepo(DelegatedOperationRepo):
 
         op.delegation_target = kwargs.get("delegation_target", None)
         op.metadata = kwargs.get("metadata") or {}
-        op.num_partitions = kwargs.get("num_partitions", None)
+        op.pipeline = kwargs.get("pipeline")
 
         context = None
         if isinstance(op.context, dict):
@@ -218,30 +222,25 @@ class MongoDelegatedOperationRepo(DelegatedOperationRepo):
             )
         elif isinstance(op.context, ExecutionContext):
             context = op.context
-        if not op.dataset_id:
-            # For consistency, set the dataset_id using the
-            # ExecutionContext.dataset
-            # rather than calling load_dataset() on a potentially stale
-            # dataset_name in the request_params
-            try:
-                op.dataset_id = context.dataset._doc.id
-            except:
-                # If we can't resolve the dataset_id, it is possible the
-                # dataset doesn't exist (deleted/being created). However,
-                # it's also possible that future operators can run
-                # dataset-less, so don't raise an error here and just log it
-                # in case we need to debug later.
-                logger.debug("Could not resolve dataset_id for operation. ")
-        elif op.dataset_id:
-            # If the dataset_id is provided, we set it in the request_params
-            # to ensure that the operation is executed on the correct dataset
-            context.request_params["dataset_id"] = str(op.dataset_id)
-            context.request_params["dataset_name"] = context.dataset.name
+
+        # For consistency, set the dataset_id using the
+        # ExecutionContext.dataset
+        # rather than calling load_dataset() on a potentially stale
+        # dataset_name in the request_params
+        try:
+            op.dataset_id = context.dataset._doc.id
+        except:
+            # If we can't resolve the dataset_id, it is possible the
+            # dataset doesn't exist (deleted/being created). However,
+            # it's also possible that future operators can run
+            # dataset-less, so don't raise an error here and just log it
+            # in case we need to debug later.
+            logger.debug("Could not resolve dataset_id for operation. ")
 
         op.context = context
         doc = self._collection.insert_one(op.to_pymongo())
         op.id = doc.inserted_id
-        return DelegatedOperationDocument().from_pymongo(op.__dict__)
+        return op
 
     def set_pinned(
         self, _id: ObjectId, pinned: bool = True
@@ -385,25 +384,6 @@ class MongoDelegatedOperationRepo(DelegatedOperationRepo):
             return_document=pymongo.ReturnDocument.AFTER,
         )
 
-        if (
-            doc
-            and doc.get("num_partitions")
-            and run_state is ExecutionRunState.FAILED
-        ):
-            # If a parent operation is failed, also mark the children as failed
-            self._collection.update_many(
-                {
-                    "group_id": doc["_id"],
-                    "run_state": {"$nin": ["failed", "completed"]},
-                },
-                {
-                    "$set": {
-                        **update["$set"],
-                        "result": {"error": "parent operation failed"},
-                    }
-                },
-            )
-
         return (
             DelegatedOperationDocument().from_pymongo(doc)
             if doc is not None
@@ -539,6 +519,8 @@ class MongoDelegatedOperationRepo(DelegatedOperationRepo):
 
     def get(self, _id: ObjectId) -> DelegatedOperationDocument:
         doc = self._collection.find_one(filter={"_id": _id})
+        if doc is None:
+            raise ValueError(f"No operation found with ID {_id}")
         return DelegatedOperationDocument().from_pymongo(doc)
 
     def count(self, filters: dict = None, search: dict = None) -> int:
@@ -556,6 +538,14 @@ class MongoDelegatedOperationRepo(DelegatedOperationRepo):
 
         return self._collection.count_documents(filter=query)
 
+    def ping(self, _id: ObjectId):
+        doc = self._collection.find_one_and_update(
+            filter={"_id": _id},
+            update={"$set": {"updated_at": datetime.utcnow()}},
+            return_document=pymongo.ReturnDocument.AFTER,
+        )
+        return DelegatedOperationDocument().from_pymongo(doc)
+
     def _extract_search_query(self, search):
         if search:
             or_query = {"$or": []}
