@@ -8,7 +8,11 @@ FiftyOne delegated operations.
 
 import asyncio
 import logging
+import logging.handlers
+import multiprocessing
+import os
 import traceback
+import psutil
 
 from fiftyone.factory.repo_factory import RepositoryFactory
 from fiftyone.factory import DelegatedOperationPagingParams
@@ -24,6 +28,76 @@ from fiftyone.operators.executor import (
 logger = logging.getLogger(__name__)
 
 
+def _configure_child_logging(queue):
+    """Configures logging in a child process to send logs to a queue.
+
+    This function should be called at the start of the target function
+    for any new process. It clears all existing handlers from the root
+    logger and adds a QueueHandler.
+    """
+    root_logger = logging.getLogger("fiftyone")
+    root_logger.handlers.clear()
+    queue_handler = logging.handlers.QueueHandler(queue)
+    root_logger.addHandler(queue_handler)
+
+
+def _execute_operator_in_child_process(
+    operation_id, log=False, log_queue=None
+):
+    """Worker function to be run in a separate 'spawned' process.
+
+    This function receives a simple ID, not a complex object, to avoid
+    serialization (pickling) errors. It instantiates its own service to create
+    fresh resources and then fetches the operation document from the database.
+
+    Args:
+        operation_id: the string ID of the operation to execute
+        log (False): the optional boolean flag to log the execution
+        log_queue (None): a multiprocessing queue to send log records to
+    """
+    # On POSIX systems, become the session leader to take control of any
+    # subprocesses. This allows the parent to terminate the entire process
+    # group reliably.
+    if hasattr(os, "setsid"):
+        try:
+            os.setsid()
+        except Exception:
+            pass
+
+    if log_queue:
+        _configure_child_logging(log_queue)
+
+    logger = logging.getLogger(__name__)
+    service = DelegatedOperationService()
+    result = None
+
+    try:
+        operation = service.get(operation_id)
+        if not operation:
+            logger.error(
+                "Operation %s not found in child process. Aborting.",
+                operation_id,
+            )
+            return
+        if log:
+            logger.info(
+                "\nRunning operation %s (%s) in child process",
+                operation.id,
+                operation.operator,
+            )
+
+        result = asyncio.run(service._execute_operator(operation))
+
+        service.set_completed(doc_id=operation.id, result=result)
+        if log:
+            logger.info("Operation %s complete", operation.id)
+    except Exception:
+        result = ExecutionResult(error=traceback.format_exc())
+        service.set_failed(doc_id=operation_id, result=result)
+        if log:
+            logger.error("Operation %s failed\n%s", operation_id, result.error)
+
+
 class DelegatedOperationService(object):
     """Service for executing delegated operations."""
 
@@ -40,6 +114,7 @@ class DelegatedOperationService(object):
         delegation_target=None,
         context=None,
         metadata=None,
+        pipeline=None,
     ):
         """Queues the given delegated operation for execution.
 
@@ -53,17 +128,22 @@ class DelegatedOperationService(object):
             metadata (None): an optional metadata dict containing properties below:
                 - inputs_schema: the schema of the operator's inputs
                 - outputs_schema: the schema of the operator's outputs
+            pipeline (None): an optional
+                :class:`fiftyone.operators.types.Pipeline` to use for
+                the operation, if this is a pipeline operator
 
         Returns:
             a :class:`fiftyone.factory.repos.DelegatedOperationDocument`
         """
-        return self._repo.queue_operation(
+        operation = self._repo.queue_operation(
             operator=operator,
             label=label if label else operator,
             delegation_target=delegation_target,
             context=context,
             metadata=metadata,
+            pipeline=pipeline,
         )
+        return operation
 
     def set_progress(self, doc_id, progress):
         """Sets the progress of the given delegated operation.
@@ -319,7 +399,7 @@ class DelegatedOperationService(object):
         doc = self._repo.get(_id=doc_id)
         if doc is None:
             raise ValueError(f"No delegated operation with {doc_id=} found")
-        if doc.group_id:
+        if doc.parent_id:
             raise ValueError("Cannot rerun a child delegated operation.")
         return self._repo.queue_operation(**doc.__dict__)
 
@@ -427,6 +507,8 @@ class DelegatedOperationService(object):
         dataset_name=None,
         limit=None,
         log=False,
+        monitor=False,
+        check_interval_seconds=60,
         **kwargs,
     ):
         """Executes queued delegated operations matching the given criteria.
@@ -442,6 +524,8 @@ class DelegatedOperationService(object):
                 operations to execute
             log (False): the optional boolean flag to log the execution of the
                 delegated operations
+            monitor (False): if we should monitor the state of the operator in a subprocess.
+            check_interval_seconds (60): how many seconds to wait between polling operator status.
         """
         results = []
         if limit is not None:
@@ -459,7 +543,14 @@ class DelegatedOperationService(object):
         )
 
         for op in queued_ops:
-            results.append(self.execute_operation(operation=op, log=log))
+            results.append(
+                self.execute_operation(
+                    operation=op,
+                    log=log,
+                    monitor=monitor,
+                    check_interval_seconds=check_interval_seconds,
+                )
+            )
         return results
 
     def count(self, filters=None, search=None):
@@ -475,7 +566,13 @@ class DelegatedOperationService(object):
         return self._repo.count(filters=filters, search=search)
 
     def execute_operation(
-        self, operation, log=False, run_link=None, log_path=None
+        self,
+        operation,
+        log=False,
+        run_link=None,
+        log_path=None,
+        monitor=False,
+        check_interval_seconds=60,
     ):
         """Executes the given delegated operation.
 
@@ -487,8 +584,9 @@ class DelegatedOperationService(object):
             run_link (None): an optional link to orchestrator-specific
                 information about the operation
             log_path (None): an optional path to the log file for the operation
+            monitor (False): if we should monitor the state of the operator in a subprocess.
+            check_interval_seconds (60): how many seconds to wait between polling operator status.
         """
-        result = None
         try:
             succeeded = (
                 self.set_running(
@@ -507,7 +605,7 @@ class DelegatedOperationService(object):
                         operation.id,
                         operation.operator,
                     )
-                return result
+                return None
 
             if log:
                 logger.info(
@@ -516,14 +614,36 @@ class DelegatedOperationService(object):
                     operation.operator,
                 )
 
-            result = asyncio.run(self._execute_operator(operation))
+            if monitor:
+                return self._execute_operation_multi_proc(
+                    operation, log, check_interval_seconds
+                )
+            return self._execute_operation_sync(operation, log)
+        except Exception as e:
+            logger.exception("Uncaught exception when executing operator")
+            err = ExecutionResult(error=traceback.format_exc())
+            try:
+                self.set_failed(doc_id=operation.id, result=err)
+            except Exception:
+                logger.exception(
+                    "Failed to mark operation %s as FAILED", operation.id
+                )
+            return err
 
+    def _execute_operation_sync(self, operation, log=False):
+        """Executes an operation synchronously in the current process."""
+        try:
+            result = asyncio.run(self._execute_operator(operation))
             self.set_completed(doc_id=operation.id, result=result)
             if log:
                 logger.info("Operation %s complete", operation.id)
-        except:
+        except Exception as e:
+            logger.debug(
+                "Uncaught exception when executing operator. Error=%s",
+                e,
+                exc_info=True,
+            )
             result = ExecutionResult(error=traceback.format_exc())
-
             self.set_failed(doc_id=operation.id, result=result)
             if log:
                 logger.info(
@@ -531,6 +651,155 @@ class DelegatedOperationService(object):
                 )
         return result
 
+    def _execute_operation_multi_proc(
+        self, operation, log=False, check_interval_seconds=60
+    ):
+        """Executes an operation in a separate process and monitors it."""
+        ctx = multiprocessing.get_context("spawn")
+        log_queue = ctx.Queue()
+
+        root_logger = logging.getLogger("fiftyone")
+        listener = logging.handlers.QueueListener(
+            log_queue, *root_logger.handlers
+        )
+        listener.start()
+
+        result = None
+        child_process = None
+        try:
+            child_process = ctx.Process(
+                target=_execute_operator_in_child_process,
+                args=(operation.id, log, log_queue),
+            )
+            child_process.start()
+
+            result = self._monitor_operation(
+                child_process, operation.id, check_interval_seconds
+            )
+
+            if not result:
+                try:
+                    final_doc = self.get(operation.id)
+                except Exception as e:
+                    logger.exception(
+                        "Failed to fetch final doc for operation %s",
+                        operation.id,
+                    )
+                    return ExecutionResult(error=f"Finalization error: {e}")
+                raw = final_doc.result if final_doc else None
+                if isinstance(raw, ExecutionResult):
+                    result = raw
+                elif isinstance(raw, dict):
+                    result = ExecutionResult(
+                        result=raw.get("result"),
+                        error=raw.get("error"),
+                        error_message=raw.get("error_message"),
+                        delegated=raw.get("delegated", False),
+                        outputs_schema=raw.get("outputs_schema"),
+                    )
+                else:
+                    result = ExecutionResult()
+        finally:
+            listener.stop()
+            if child_process and child_process.is_alive():
+                self._terminate_child_process(
+                    child_process, operation.id, "Executor shutting down"
+                )
+
+        return result
+
+    def _monitor_operation(
+        self, child_process, operation_id, check_interval_seconds=60
+    ):
+        """
+        Monitors the child_process and operation state for failures.
+        """
+        while child_process.is_alive():
+            child_process.join(timeout=check_interval_seconds)
+
+            if not child_process.is_alive():
+                return None
+
+            try:
+                op_doc = self.get(operation_id)
+                if op_doc and op_doc.run_state == ExecutionRunState.FAILED:
+                    err = None
+                    res = getattr(op_doc, "result", None)
+                    if isinstance(res, dict):
+                        err = res.get("error")
+                    else:
+                        err = getattr(res, "error", None)
+
+                    reason = (
+                        "Operation marked as FAILED externally"
+                        if not err or "marked as failed" in str(err).lower()
+                        else f"Operation FAILED (detected by monitor): {err}"
+                    )
+                    self._terminate_child_process(
+                        child_process, operation_id, reason
+                    )
+                    return ExecutionResult(error=reason)
+                else:
+                    logger.debug("Pinging operation %s", operation_id)
+                    self._repo.ping(operation_id)
+            except Exception as e:
+                reason = f"Error in monitoring loop: {e}"
+                logger.error(
+                    "Error in monitoring loop for operation %s: %s",
+                    operation_id,
+                    e,
+                )
+                self._terminate_child_process(
+                    child_process, operation_id, reason
+                )
+                return ExecutionResult(error=reason)
+
+    def _terminate_child_process(self, child_process, operation_id, reason):
+        """
+        Terminates a child process and its descendants using psutil.
+        """
+        pid = child_process.pid
+        logger.warning(
+            "Terminating process tree (PID: %d) for operation %s. Reason: %s",
+            pid,
+            operation_id,
+            reason,
+        )
+
+        try:
+            parent = psutil.Process(pid)
+            children = parent.children(recursive=True)
+
+            for child in children:
+                try:
+                    child.terminate()
+                except psutil.NoSuchProcess:
+                    pass
+
+            _, alive = psutil.wait_procs(children, timeout=10)
+
+            for p in alive:
+                try:
+                    p.kill()
+                except psutil.NoSuchProcess:
+                    pass
+            try:
+                parent.terminate()
+                parent.wait(timeout=10)
+                if parent.is_running():
+                    parent.kill()
+                    parent.wait(timeout=5)
+            except psutil.NoSuchProcess:
+                pass
+        except psutil.NoSuchProcess:
+            logger.info(
+                "Process %d for op %s already terminated.", pid, operation_id
+            )
+        except Exception as e:
+            logger.error(
+                "Error during process tree termination for PID %d: %s", pid, e
+            )
+
     async def _execute_operator(self, doc):
         operator_uri = doc.operator
         context = doc.context
