@@ -10,20 +10,19 @@ import asyncio
 import collections
 import inspect
 import logging
-import os
 import traceback
 
-from typing import Optional
-
 import fiftyone as fo
 import fiftyone.core.dataset as fod
 import fiftyone.core.media as fom
 import fiftyone.core.odm.utils as focu
 import fiftyone.core.utils as fou
 import fiftyone.core.view as fov
+from fiftyone.operators import constants
 from fiftyone.operators.decorators import coroutine_timeout
 from fiftyone.operators.message import GeneratedMessage, MessageType
 from fiftyone.operators.operations import Operations
+from fiftyone.operators.operator import PipelineOperator
 from fiftyone.operators.panel import PanelRef
 from fiftyone.operators.registry import OperatorRegistry
 from fiftyone.operators.store import ExecutionStore
@@ -239,8 +238,7 @@ async def execute_or_delegate_operator(
     prepared = await prepare_operator_executor(operator_uri, request_params)
     if isinstance(prepared, ExecutionResult):
         raise prepared.to_exception()
-    else:
-        operator, executor, ctx, inputs = prepared
+    operator, executor, ctx, inputs = prepared
 
     execution_options = operator.resolve_execution_options(ctx)
     if (
@@ -269,6 +267,28 @@ async def execute_or_delegate_operator(
             )
             should_delegate = True
 
+    # Validate PipelineOperators
+    pipeline = None
+    if isinstance(operator, PipelineOperator):
+        try:
+            pipeline = operator.resolve_pipeline(ctx)
+            if not pipeline or not isinstance(pipeline, types.Pipeline):
+                raise TypeError(
+                    "Pipeline must be a fiftyone.operators.types.Pipeline"
+                )
+            if not all(
+                isinstance(s, types.PipelineStage) for s in pipeline.stages
+            ):
+                raise TypeError(
+                    "Pipeline stages must be of type PipelineStage"
+                )
+        except Exception as e:
+            return ExecutionResult(
+                executor=executor,
+                error=traceback.format_exc(),
+                error_message=f"Failed to resolve pipeline: {str(e)}",
+            )
+
     if should_delegate:
         try:
             from .delegated import DelegatedOperationService
@@ -278,10 +298,14 @@ async def execute_or_delegate_operator(
                 ctx.num_distributed_tasks
                 or "num_distributed_tasks" in ctx.request_params
             ):
-                logger.warning(
-                    "Distributed execution only supported in FiftyOne Enterprise"
+                raise ValueError(
+                    "Distributed execution is only supported in FiftyOne Enterprise"
+                )
+            if isinstance(operator, PipelineOperator):
+                raise ValueError(
+                    "Pipeline operators require a distributed executor, "
+                    "available only in FiftyOne Enterprise"
                 )
-                ctx.request_params.pop("num_distributed_tasks", None)
 
             ctx.request_params["delegated"] = True
             metadata = {"inputs_schema": None, "outputs_schema": None}
@@ -300,6 +324,7 @@ async def execute_or_delegate_operator(
                 delegation_target=ctx.delegation_target,
                 label=operator.resolve_run_name(ctx),
                 metadata=metadata,
+                pipeline=None,  # pipelines not supported in this repo
             )
 
             execution = ExecutionResult(
@@ -310,6 +335,11 @@ async def execute_or_delegate_operator(
                 if execution.result["context"]
                 else None
             )
+            execution.result["pipeline"] = (
+                execution.result["pipeline"].to_json()
+                if execution.result["pipeline"]
+                else None
+            )
             return execution
         except Exception as error:
             return ExecutionResult(
@@ -318,8 +348,13 @@ async def execute_or_delegate_operator(
                 error_message=str(error),
             )
     else:
+        if isinstance(operator, PipelineOperator):
+            raise NotImplementedError(
+                "Immediate execution of pipeline operators is not supported"
+            )
         # Not delegated, force distributed execution off
         ctx.request_params.pop("num_distributed_tasks", None)
+
         try:
             result = await do_execute_operator(operator, ctx, exhaust=exhaust)
         except Exception as error:
@@ -545,7 +580,7 @@ class ExecutionContext(object):
         # id if it is available
         uid = self.request_params.get("dataset_id", None)
         if uid:
-            self._dataset = focu.load_dataset(id=uid)
+            self._dataset = focu.load_dataset(id=uid, reload=True)
 
             # Set the dataset_name using the dataset object in case the dataset
             # has been renamed or changed since the context was created
@@ -553,12 +588,7 @@ class ExecutionContext(object):
         else:
             uid = self.request_params.get("dataset_name", None)
             if uid:
-                self._dataset = focu.load_dataset(name=uid)
-
-        # TODO: refactor so that this additional reload post-load is not
-        #  required
-        if self._dataset is not None:
-            self._dataset.reload()
+                self._dataset = focu.load_dataset(name=uid, reload=True)
 
         if (
             self.group_slice is not None
@@ -588,7 +618,6 @@ class ExecutionContext(object):
         if self._view is not None:
             return self._view
 
-        # Always derive the view from the context's dataset
         dataset = self.dataset
         view_name = self.request_params.get("view_name", None)
         stages = self.request_params.get("view", None)
@@ -604,7 +633,6 @@ class ExecutionContext(object):
                 stages=stages,
                 filters=filters,
                 extended_stages=extended,
-                reload=False,
             )
         else:
             self._view = dataset.load_saved_view(view_name)
@@ -612,8 +640,7 @@ class ExecutionContext(object):
         return self._view
 
     def target_view(self, param_name="view_target"):
-        """The target :class:`fiftyone.core.view.DatasetView` for the operator
-        being executed.
+        """The target view for the operator being executed.
 
         Args:
             param_name ("view_target"): the name of the enum parameter defining
@@ -622,25 +649,34 @@ class ExecutionContext(object):
         Returns:
             a :class:`fiftyone.core.collections.SampleCollection`
         """
-        target = self.params.get(param_name, None)
-        if target == "SELECTED_SAMPLES":
-            return self.view.select(self.selected)
-        if target == "DATASET":
+        target = self.params.get(param_name)
+
+        if target == constants.ViewTarget.CURRENT_VIEW:
+            return self.view
+        if target == constants.ViewTarget.DATASET:
             return self.dataset
-        return self.view
+        if target == constants.ViewTarget.BASE_VIEW:
+            return self.view._base_view  # pylint: disable=protected-access
+        if target == constants.ViewTarget.SELECTED_SAMPLES:
+            return self.view.select(self.selected)
+        if target == constants.ViewTarget.SELECTED_LABELS:
+            return self.view.select_labels(self.selected_labels)
+        if target == constants.ViewTarget.DATASET_VIEW:
+            return self.dataset.view()
+
+        return self.view if self.has_custom_view else self.dataset
+
+    # Alias for common word reversal
+    view_target = target_view
 
     @property
     def has_custom_view(self):
         """Whether the operator has a custom view."""
-        stages = self.request_params.get("view", None)
-        filters = self.request_params.get("filters", None)
-        extended = self.request_params.get("extended", None)
-        has_stages = stages is not None and stages != [] and stages != {}
-        has_filters = filters is not None and filters != [] and filters != {}
-        has_extended = (
-            extended is not None and extended != [] and extended != {}
-        )
-        return has_stages or has_filters or has_extended
+        has_stages = bool(self.request_params.get("view", None))
+        has_filters = bool(self.request_params.get("filters", None))
+        has_extended = bool(self.request_params.get("extended", None))
+        has_saved_view = bool(self.request_params.get("view_name", None))
+        return has_stages or has_filters or has_extended or has_saved_view
 
     @property
     def spaces(self):
