@@ -1,21 +1,22 @@
 """
 FiftyOne Server tags and tagging
 
-| Copyright 2017-2023, Voxel51, Inc.
+| Copyright 2017-2025, Voxel51, Inc.
 | `voxel51.com <https://voxel51.com/>`_
 |
 """
+
 import typing as t
 
 import fiftyone.core.collections as foc
-import fiftyone.core.media as fom
 import fiftyone.core.view as fov
-from fiftyone.server.filters import SampleFilter
+from fiftyone.core.utils import run_sync_task
 
+from fiftyone.server.filters import SampleFilter
 import fiftyone.server.view as fosv
 
 
-def get_tag_view(
+async def get_tag_view(
     dataset: str,
     stages: t.List,
     filters: t.Dict,
@@ -27,29 +28,29 @@ def get_tag_view(
     target_labels: bool = False,
     sample_ids: t.List[str] = None,
 ) -> foc.SampleCollection:
-    view = fosv.get_view(
+    view = await fosv.get_view(
         dataset,
         stages=stages,
         filters=filters,
         extended_stages=extended_stages,
         sample_filter=sample_filter,
+        awaitable=True,
     )
 
-    if sample_ids:
-        view = fov.make_optimized_select_view(view, sample_ids)
+    def run(view):
+        if sample_ids:
+            view = fov.make_optimized_select_view(
+                view, sample_ids, flatten=True
+            )
 
-    if view.media_type == fom.GROUP:
-        if labels or (
-            sample_filter.group.id and not sample_filter.group.slice
-        ):
-            view = view.select_group_slices(_allow_mixed=True)
+        if target_labels:
+            if labels:
+                view = view.select_labels(labels)
+            elif hidden_labels:
+                view = view.exclude_labels(hidden_labels)
+            elif label_fields:
+                view = view.select_fields(label_fields)
 
-    if target_labels:
-        if labels:
-            view = view.select_labels(labels)
-        elif hidden_labels:
-            view = view.exclude_labels(hidden_labels)
-        elif label_fields:
-            view = view.select_fields(label_fields)
+        return view
 
-    return view
+    return await run_sync_task(run, view)
