@@ -1039,10 +1039,10 @@ def load_annotations(
                 unexpected labels
             -   ``"ignore"``: automatically ignore any unexpected labels
             -   ``"keep"``: automatically keep all unexpected labels in a field
-                whose name matches the the label type
+                whose name matches the label type
             -   ``"return"``: return a dict containing all unexpected labels,
                 or ``None`` if there aren't any
-        cleanup (False): whether to delete any informtation regarding this run
+        cleanup (False): whether to delete any information regarding this run
             from the annotation backend after loading the annotations
         progress (None): whether to render a progress bar (True/False), use the
             default value ``fiftyone.config.show_progress_bars`` (None), or a
@@ -2318,7 +2318,7 @@ class AnnotationResults(foa.AnnotationResults):
 
     @property
     def _is_frames(self):
-        """Whether this annotation run was perfromed on a frames view."""
+        """Whether this annotation run was performed on a frames view."""
         return "_frames" in self.id_map
 
     def _finalize_id_map(self):
