@@ -1,8 +1,8 @@
 """
 Utilities for working with datasets in
-`Berkeley DeepDrive (BDD) format <https://bdd-data.berkeley.edu>`_.
+`Berkeley DeepDrive (BDD) format <http://bdd-data.berkeley.edu>`_.
 
-| Copyright 2017-2023, Voxel51, Inc.
+| Copyright 2017-2025, Voxel51, Inc.
 | `voxel51.com <https://voxel51.com/>`_
 |
 """
@@ -17,7 +17,7 @@ import eta.core.utils as etau
 import fiftyone as fo
 import fiftyone.core.labels as fol
 import fiftyone.core.metadata as fom
-import fiftyone.core.utils as fou
+import fiftyone.core.storage as fos
 import fiftyone.utils.data as foud
 
 
@@ -175,7 +175,7 @@ class BDDDatasetImporter(
         if self.labels_path is not None and os.path.isfile(self.labels_path):
             anno_dict_map = load_bdd_annotations(self.labels_path)
             anno_dict_map = {
-                fou.normpath(k): v for k, v in anno_dict_map.items()
+                fos.normpath(k): v for k, v in anno_dict_map.items()
             }
         else:
             anno_dict_map = {}
@@ -258,7 +258,7 @@ class BDDDatasetExporter(
             generate an output path for each exported image. This argument
             allows for populating nested subdirectories that match the shape of
             the input paths. The path is converted to an absolute path (if
-            necessary) via :func:`fiftyone.core.utils.normalize_path`
+            necessary) via :func:`fiftyone.core.storage.normalize_path`
         abs_paths (False): whether to store absolute paths to the images in the
             exported labels
         image_format (None): the image format to use when writing in-memory
@@ -409,7 +409,7 @@ def parse_bdd100k_dataset(
                 data/
 
     Args:
-        source_dir: the source directory containing the manually dowloaded
+        source_dir: the source directory containing the manually downloaded
             BDD100K files
         dataset_dir: the directory to construct the output split directories
         copy_files (True): whether to move (False) or create copies (True) of
@@ -519,7 +519,7 @@ def _parse_bdd_annotation(d, frame_size, extra_attrs):
     # Frame attributes
     #
     # @todo problems may occur if frame attributes have names "detections" or
-    # "polylines", but we cross our fingers and proceeed
+    # "polylines", but we cross our fingers and proceed
     #
     frame_labels = _parse_frame_labels(d.get("attributes", {}))
     labels.update(frame_labels)
