@@ -1,7 +1,7 @@
 """
 Sample parsers.
 
-| Copyright 2017-2023, Voxel51, Inc.
+| Copyright 2017-2025, Voxel51, Inc.
 | `voxel51.com <https://voxel51.com/>`_
 |
 """
@@ -9,7 +9,6 @@ import os
 
 import numpy as np
 
-import eta.core.image as etai
 import eta.core.serial as etas
 import eta.core.utils as etau
 
@@ -21,11 +20,18 @@ from fiftyone.core.sample import Sample
 import fiftyone.core.utils as fou
 import fiftyone.core.validation as fov
 import fiftyone.utils.eta as foue
-
-fouv = fou.lazy_import("fiftyone.utils.video")
+import fiftyone.utils.image as foui
+import fiftyone.utils.video as fouv
 
 
-def add_images(dataset, samples, sample_parser, tags=None):
+def add_images(
+    dataset,
+    samples,
+    sample_parser,
+    tags=None,
+    generator=False,
+    progress=None,
+):
     """Adds the given images to the dataset.
 
     This operation does not read the images.
@@ -41,6 +47,11 @@ def add_images(dataset, samples, sample_parser, tags=None):
             parse the samples
         tags (None): an optional tag or iterable of tags to attach to each
             sample
+        generator (False): whether to yield ID batches as a generator as
+            samples are added to the dataset
+        progress (None): whether to render a progress bar (True/False), use the
+            default value ``fiftyone.config.show_progress_bars`` (None), or a
+            progress callback function to invoke instead
 
     Returns:
         a list of IDs of the samples that were added to the dataset
@@ -77,14 +88,13 @@ def add_images(dataset, samples, sample_parser, tags=None):
 
         return Sample(filepath=image_path, metadata=metadata, tags=tags)
 
-    try:
-        num_samples = len(samples)
-    except:
-        num_samples = None
-
     _samples = map(parse_sample, samples)
     return dataset.add_samples(
-        _samples, num_samples=num_samples, expand_schema=False
+        _samples,
+        expand_schema=False,
+        generator=generator,
+        progress=progress,
+        num_samples=samples,
     )
 
 
@@ -96,6 +106,8 @@ def add_labeled_images(
     tags=None,
     expand_schema=True,
     dynamic=False,
+    generator=False,
+    progress=None,
 ):
     """Adds the given labeled images to the dataset.
 
@@ -128,6 +140,11 @@ def add_labeled_images(
             if a sample's schema is not a subset of the dataset schema
         dynamic (False): whether to declare dynamic attributes of embedded
             document fields that are encountered
+        generator (False): whether to yield ID batches as a generator as
+            samples are added to the dataset
+        progress (None): whether to render a progress bar (True/False), use the
+            default value ``fiftyone.config.show_progress_bars`` (None), or a
+            progress callback function to invoke instead
 
     Returns:
         a list of IDs of the samples that were added to the dataset
@@ -192,21 +209,25 @@ def add_labeled_images(
         dataset._ensure_label_field(label_field, sample_parser.label_cls)
         expand_schema = False
 
-    try:
-        num_samples = len(samples)
-    except:
-        num_samples = None
-
     _samples = map(parse_sample, samples)
     return dataset.add_samples(
         _samples,
         expand_schema=expand_schema,
         dynamic=dynamic,
-        num_samples=num_samples,
+        generator=generator,
+        progress=progress,
+        num_samples=samples,
     )
 
 
-def add_videos(dataset, samples, sample_parser, tags=None):
+def add_videos(
+    dataset,
+    samples,
+    sample_parser,
+    tags=None,
+    generator=False,
+    progress=None,
+):
     """Adds the given videos to the dataset.
 
     This operation does not read the videos.
@@ -222,6 +243,11 @@ def add_videos(dataset, samples, sample_parser, tags=None):
             parse the samples
         tags (None): an optional tag or iterable of tags to attach to each
             sample
+        generator (False): whether to yield ID batches as a generator as
+            samples are added to the dataset
+        progress (None): whether to render a progress bar (True/False), use the
+            default value ``fiftyone.config.show_progress_bars`` (None), or a
+            progress callback function to invoke instead
 
     Returns:
         a list of IDs of the samples that were added to the dataset
@@ -252,16 +278,14 @@ def add_videos(dataset, samples, sample_parser, tags=None):
 
         return Sample(filepath=video_path, metadata=metadata, tags=tags)
 
-    try:
-        num_samples = len(samples)
-    except:
-        num_samples = None
-
-    _samples = map(parse_sample, samples)
-
     # @todo: skip schema expansion and set media type before adding samples
+    _samples = map(parse_sample, samples)
     return dataset.add_samples(
-        _samples, num_samples=num_samples, expand_schema=True
+        _samples,
+        expand_schema=True,
+        generator=generator,
+        progress=progress,
+        num_samples=samples,
     )
 
 
@@ -273,6 +297,8 @@ def add_labeled_videos(
     tags=None,
     expand_schema=True,
     dynamic=False,
+    generator=False,
+    progress=None,
 ):
     """Adds the given labeled videos to the dataset.
 
@@ -304,6 +330,11 @@ def add_labeled_videos(
             if a sample's schema is not a subset of the dataset schema
         dynamic (False): whether to declare dynamic attributes of embedded
             document fields that are encountered
+        generator (False): whether to yield ID batches as a generator as
+            samples are added to the dataset
+        progress (None): whether to render a progress bar (True/False), use the
+            default value ``fiftyone.config.show_progress_bars`` (None), or a
+            progress callback function to invoke instead
 
     Returns:
         a list of IDs of the samples that were added to the dataset
@@ -366,17 +397,14 @@ def add_labeled_videos(
 
         return sample
 
-    try:
-        num_samples = len(samples)
-    except:
-        num_samples = None
-
     _samples = map(parse_sample, samples)
     return dataset.add_samples(
         _samples,
         expand_schema=expand_schema,
         dynamic=dynamic,
-        num_samples=num_samples,
+        generator=generator,
+        progress=progress,
+        num_samples=samples,
     )
 
 
@@ -626,7 +654,7 @@ class ImageSampleParser(UnlabeledImageSampleParser):
     def get_image(self):
         image_or_path = self.current_sample
         if etau.is_str(image_or_path):
-            return etai.read(image_or_path)
+            return foui.read(image_or_path)
 
         return np.asarray(image_or_path)
 
@@ -963,7 +991,7 @@ class LabeledImageTupleSampleParser(LabeledImageSampleParser):
 
     def _parse_image(self, image_or_path):
         if etau.is_str(image_or_path):
-            return etai.read(image_or_path)
+            return foui.read(image_or_path)
 
         return np.asarray(image_or_path)
 
@@ -1577,7 +1605,7 @@ class FiftyOneUnlabeledImageSampleParser(UnlabeledImageSampleParser):
 
     def get_image(self):
         fov.validate_image_sample(self.current_sample)
-        return etai.read(self.current_sample.filepath)
+        return foui.read(self.current_sample.filepath)
 
     def get_image_path(self):
         fov.validate_image_sample(self.current_sample)
@@ -1630,7 +1658,7 @@ class FiftyOneLabeledImageSampleParser(LabeledImageSampleParser):
 
     def get_image(self):
         fov.validate_image_sample(self.current_sample)
-        return etai.read(self.current_sample.filepath)
+        return foui.read(self.current_sample.filepath)
 
     def get_image_path(self):
         fov.validate_image_sample(self.current_sample)
@@ -1678,8 +1706,8 @@ class ExtractClipsMixin(object):
         compute_metadata (False): whether to compute
             :class:`fiftyone.core.metadata.VideoMetadata` instances on-the-fly
             when no pre-computed metadata is available
-        export_media (True): whether to actually write clips when their paths
-            are requested
+        write_clips (True): whether to write clips when their paths are
+            requested
         clip_dir (None): a directory to write clips. Only applicable when
             parsing :class:`fiftyone.core.clips.ClipView` instances
         video_format (None): the video format to use when writing video clips
@@ -1689,7 +1717,7 @@ class ExtractClipsMixin(object):
     def __init__(
         self,
         compute_metadata=False,
-        export_media=True,
+        write_clips=True,
         clip_dir=None,
         video_format=None,
     ):
@@ -1697,7 +1725,7 @@ class ExtractClipsMixin(object):
             video_format = fo.config.default_video_ext
 
         self.compute_metadata = compute_metadata
-        self.export_media = export_media
+        self.write_clips = write_clips
         self.clip_dir = clip_dir
         self.video_format = video_format
 
@@ -1707,7 +1735,7 @@ class ExtractClipsMixin(object):
         video_path = sample.filepath
         basename, ext = os.path.splitext(os.path.basename(video_path))
 
-        if self.export_media:
+        if self.write_clips:
             if self.clip_dir is None:
                 self.clip_dir = etau.make_temp_dir()
 
@@ -1724,7 +1752,7 @@ class ExtractClipsMixin(object):
         )
         clip_path = os.path.join(dirname, clip_name)
 
-        if self.export_media:
+        if self.write_clips:
             self._curr_clip_path = clip_path
             fouv.extract_clip(
                 video_path,
@@ -1757,7 +1785,7 @@ class FiftyOneUnlabeledVideoSampleParser(
             :class:`fiftyone.core.metadata.VideoMetadata` instances on-the-fly
             if :meth:`get_video_metadata` is called and no metadata is
             available
-        export_media (True): whether to write clips when :meth:`get_video_path`
+        write_clips (True): whether to write clips when :meth:`get_video_path`
             is called
         clip_dir (None): a directory to write clips. Only applicable when
             parsing :class:`fiftyone.core.clips.ClipView` instances
@@ -1768,14 +1796,14 @@ class FiftyOneUnlabeledVideoSampleParser(
     def __init__(
         self,
         compute_metadata=False,
-        export_media=True,
+        write_clips=True,
         clip_dir=None,
         video_format=None,
     ):
         ExtractClipsMixin.__init__(
             self,
             compute_metadata=compute_metadata,
-            export_media=export_media,
+            write_clips=write_clips,
             clip_dir=clip_dir,
             video_format=video_format,
         )
@@ -1830,7 +1858,7 @@ class FiftyOneLabeledVideoSampleParser(
             :class:`fiftyone.core.metadata.VideoMetadata` instances on-the-fly
             if :meth:`get_video_metadata` is called and no metadata is
             available
-        export_media (True): whether to write clips when :meth:`get_video_path`
+        write_clips (True): whether to write clips when :meth:`get_video_path`
             is called
         clip_dir (None): a directory to write clips. Only applicable when
             parsing :class:`fiftyone.core.clips.ClipView` instances
@@ -1845,7 +1873,7 @@ class FiftyOneLabeledVideoSampleParser(
         label_fcn=None,
         frame_labels_fcn=None,
         compute_metadata=False,
-        export_media=True,
+        write_clips=True,
         clip_dir=None,
         video_format=None,
     ):
@@ -1856,7 +1884,7 @@ class FiftyOneLabeledVideoSampleParser(
         ExtractClipsMixin.__init__(
             self,
             compute_metadata=compute_metadata,
-            export_media=export_media,
+            write_clips=write_clips,
             clip_dir=clip_dir,
             video_format=video_format,
         )
