@@ -1,27 +1,31 @@
 """
 Evaluation utilities.
 
-| Copyright 2017-2023, Voxel51, Inc.
+| Copyright 2017-2025, Voxel51, Inc.
 | `voxel51.com <https://voxel51.com/>`_
 |
 """
 import types
 
+from .base import get_subset_view
 from .classification import (
     evaluate_classifications,
+    ClassificationEvaluationConfig,
     ClassificationResults,
-    BinaryClassificationResults,
 )
 from .detection import (
     evaluate_detections,
+    DetectionEvaluationConfig,
     DetectionResults,
 )
 from .regression import (
     evaluate_regressions,
+    RegressionEvaluationConfig,
     RegressionResults,
 )
 from .segmentation import (
     evaluate_segmentations,
+    SegmentationEvaluationConfig,
     SegmentationResults,
 )
 
