@@ -739,14 +739,10 @@ class BaseClassificationResults(BaseEvaluationResults):
             self.ytrue, self.ypred, labels=labels, weights=self.weights
         )
 
-        precision, recall, fscore, _ = skm.precision_recall_fscore_support(
-            self.ytrue,
-            self.ypred,
+        precision, recall, fscore = self._precision_recall_fscore(
             average=average,
             labels=labels,
             beta=beta,
-            sample_weight=self.weights,
-            zero_division=0,
         )
 
         support = _compute_support(
@@ -892,6 +888,20 @@ class BaseClassificationResults(BaseEvaluationResults):
 
         return np.array([c for c in self.classes if c != self.missing])
 
+    def _precision_recall_fscore(self, labels, average, beta):
+        pos_label = getattr(self, "_pos_label", None)
+        precision, recall, fscore, _ = skm.precision_recall_fscore_support(
+            self.ytrue,
+            self.ypred,
+            average=average,
+            labels=labels,
+            beta=beta,
+            sample_weight=self.weights,
+            zero_division=0,
+            pos_label=pos_label if average == "binary" else None,
+        )
+        return precision, recall, fscore
+
     def _confusion_matrix(
         self,
         classes=None,
